summaryrefslogtreecommitdiff
path: root/round-robin.sh
diff options
context:
space:
mode:
Diffstat (limited to 'round-robin.sh')
-rw-r--r--round-robin.sh10
1 files changed, 6 insertions, 4 deletions
diff --git a/round-robin.sh b/round-robin.sh
index 3d043455..034e6726 100644
--- a/round-robin.sh
+++ b/round-robin.sh
@@ -54,12 +54,14 @@ reset_artifacts ()
echo "Starting build" > ${rr[top_artifacts]}/results
echo "-10" >> ${rr[top_artifacts]}/results
+ local single_branch=${rr[baseline_branch]}
+
# Clone base-artifacts so that run_step can rsync artifacts for skipped
# steps.
# TODO: base-artifacts repo is starting to get big, so we should
# fetch only the $baseline branch, instead of all branches.
rr[base-artifacts_rev]="${rr[base-artifacts_rev]-${rr[baseline_branch]}}"
- clone_or_update_repo base-artifacts ${rr[base-artifacts_rev]} https://git-us.linaro.org/toolchain/ci/base-artifacts.git
+ clone_or_update_repo base-artifacts ${rr[base-artifacts_rev]} https://git-us.linaro.org/toolchain/ci/base-artifacts.git auto $single_branch
cat <<EOF | manifest_out
rr[base-artifacts_rev]=$(git_rev_parse_long base-artifacts HEAD)
EOF
@@ -108,7 +110,7 @@ clone_repo ()
fi
# Clone origin remote
- clone_or_update_repo_no_checkout $project ${rr[${project}_url]} auto > /dev/null
+ clone_or_update_repo_no_checkout $project ${rr[${project}_url]} auto "" > /dev/null
# Add baseline remote
git_init_linaro_local_remote $project baseline $read_only
# Checkout, now that we have both origin and baseline remotes ready.
@@ -54,12 +54,14 @@ reset_artifacts ()
# Clone base-artifacts so that run_step can rsync artifacts for skipped
# steps.
- # TODO: base-artifacts repo is starting to get big, so we should
- # fetch only the $baseline branch, instead of all branches.
+ # base-artifacts repo is big and changes all the time, so we
+ # fetch only the $baseline_branch, instead of all branches.
rr[base-artifacts_rev]="${rr[base-artifacts_rev]-${rr[baseline_branch]}}"